Python API
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 3

   srtk.knowledge_graph
   srtk.preprocessing
   srtk.scorer


srtk.link\_wikidata module
--------------------------

.. automodule:: srtk.link
   :members:

srtk.preprocess module
----------------------

.. automodule:: srtk.preprocess
   :members:

srtk.retrieve module
--------------------

.. automodule:: srtk.retrieve
   :members:

srtk.train module
-----------------

.. automodule:: srtk.train
   :members:
   :undoc-members:
   :show-inheritance:

srtk.visualize module
---------------------

.. automodule:: srtk.visualize
   :members: